@@ -1,16 +1,13 @@
 """
-Handpick is a tool to traverse nested data structures recursively and
-find all objects that meet certain criteria.
+Handpick is a tool to traverse nested data structures and pick all
+objects that meet certain criteria.
 """
 
 from .core import (
     pick,
     Predicate,
     is_type,
-    not_type,
     no_error,
-    IS_COLLECTION,
-    IS_MAPPING,
     INT_STR,
     FLOAT_STR,
     NUM_STR,
@@ -18,17 +15,14 @@ from .core import (
     max_depth,
 )
 
-__version__ = "0.11.0"
+__version__ = "0.12.0"
 
 __all__ = (
     "__version__",
     "pick",
     "Predicate",
     "is_type",
-    "not_type",
     "no_error",
-    "IS_COLLECTION",
-    "IS_MAPPING",
     "INT_STR",
     "FLOAT_STR",
     "NUM_STR",
